@@ -55,7 +55,7 @@ class BaseAdaptorField(object):
         self.config['field_name'] = self.field_name_render
         self.config['app_label'] = self.model._meta.app_label
         self.config['module_name'] = self.model._meta.module_name
-        self.config['filters_to_show'] = self.filters_to_show
+        self.config['filters_to_show'] = filters_to_show
         self.config['can_auto_save'] = self.config.get('can_auto_save', 1)
 
         filters_to_edit = self.config.get('filters_to_edit', None)
